/**
 *
 */
package com.snail.msglet.sample;

import com.snail.msglet.Msglet;
import com.snail.msglet.Request;
import com.snail.msglet.Response;

import java.util.Map;


/**
 * メニューMsglet.
 * @author kagyuu
 *
 */
public final class MenuMsglet extends Msglet {
  /**
   * 終了処理.
   * @see com.snail.msglet.Msglet#destroy()
   */
  @Override
  public void destroy() {
  }

  /**
   * 初期化処理.
   * @param initParam 初期化Map
   * @see com.snail.msglet.Msglet#init(java.util.Map)
   */
  @Override
  public void init(final Map initParam) {
  }

  /**
   * リクエスト処理.
   * <pre>
   * 選択された Msglet に処理を委譲します。
   * 選択された Msglet が無い場合には、メニューを表示します。
   * </pre>
   * @param req リクエスト
   * @param res レスポンス
   * @see com.snail.msglet.Msglet#service(
   *                                 com.snail.msglet.Request,
   *                                 com.snail.msglet.Response)
   */
  @Override
  public void service(final Request req, final Response res) {
    // Msglet が選択されているかを調べる
    for (String msg : req.getMsg().split("\n")) {
      if (
        (msg.indexOf("[v]") > 0) || (msg.indexOf("[ v]") > 0)
          || (msg.indexOf("[v ]") > 0)) {
        // Msglet が選択されていた場合には処理を委譲する
        String msgletName =
          msg.substring(msg.indexOf("]") + 1, msg.length()).trim();

        req.setMsg("");

        req.getRequestDispatcher(msgletName).forward(req, res);

        return;
      }
    }

    // メニューの表示
    StringBuilder sb = new StringBuilder();
    sb.append("MENU (write v on [ ], and response this msg.)\n\n");

    for (String msgletName : req.getMsgletNames()) {
      sb.append("[ ]");
      sb.append(msgletName);
      sb.append("\n");
    }

    res.setMsg(sb.toString());
  }
}
