package com.snail.msglet.sample;

import com.snail.msglet.Msglet;
import com.snail.msglet.Request;
import com.snail.msglet.Response;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.LinkedList;
import java.util.Map;


/**
 * Msgletのサンプル実装です .
 * <pre>
 * 受信したメッセージを最大 history 回保持して、
 * 送信者に返します。
 * hisotry は、msg.xml の Msglet 初期化パラメータ
 * に記述します。(省略時は３回まで)
 * </pre>
 * @author kagyuu
  */
public final class SampleMsglet extends Msglet {
  /** commons logging. */
  private static Log logger = LogFactory.getLog(SampleMsglet.class);

  /**
   * 何回までメッセージを取っておくか .
   */
  private int history = 2;

  /**
   * Msgletが終了するときに呼ばれます .
   */
  @Override
  public void destroy() {
    logger.info("---- This Msglet is Terminated ----");
  }

  /**
   * メッセージを受信したときに呼ばれます .
   *
   * @param req リクエスト
   * @param res レスポンス
   */
  @Override
  public void service(final Request req, final Response res) {
    logger.info("---- Service is called ----");

    if ("".equals(req.getMsg())) {
      // "" が入力されていた場合には、初期画面を表示
      res.setMsg("Input Message:");

      return;
    }

    if ("end".equals(req.getMsg())) {
      // "end" が入力されていた場合には、"Menu"に戻る
      req.getRequestDispatcher("Menu").forward(req, res);

      return;
    }

    Map<String, Object> session = req.getSession();

    LinkedList<String> msgList;

    if (session.containsKey("SambpleMsglet.history")) {
      msgList = (LinkedList<String>) session.get("SambpleMsglet.history");
    } else {
      msgList = new LinkedList<String>();
    }

    msgList.add(req.getMsg());

    while (msgList.size() > history) {
      msgList.removeFirst();
    }

    session.put("SambpleMsglet.history", msgList);

    res.setMsg(msgList.toString());
  }

  /**
   * Msglet が初期化されるときに呼ばれます .
   *
   * @param initParam 初期化パラメータ
   */
  @Override
  public void init(final Map initParam) {
    logger.info("---- This Msglet is Initialized ----");
    logger.info(initParam.toString());

    try {
      history = Integer.parseInt((String) initParam.get("history"));
    } catch (Exception ignoreEx) {
      ignoreEx = null;
    }
  }
}
